@@ -1,9 +1,9 @@
 # Verilog - Verilog Perl Interface
-# $Revision: #26 $$Date: 2003/10/02 $$Author: wsnyder $
+# $Revision: #28 $$Date: 2004/01/27 $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2000-2003 by Wilson Snyder.  This program is free software;
+# Copyright 2000-2004 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -25,7 +25,7 @@ use Verilog::Netlist::Pin;
 use Verilog::Netlist::Subclass;
 @ISA = qw(Verilog::Netlist::Module::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '2.230';
+$VERSION = '2.231';
 use strict;
 
 structs('new',
@@ -205,13 +205,13 @@ sub dump {
     my $norecurse = shift;
     print " "x$indent,"Module:",$self->name(),"  File:",$self->filename(),"\n";
     if (!$norecurse) {
-	foreach my $portref (values %{$self->ports}) {
+	foreach my $portref ($self->ports_sorted) {
 	    $portref->dump($indent+2);
 	}
-	foreach my $netref (values %{$self->nets}) {
+	foreach my $netref ($self->nets_sorted) {
 	    $netref->dump($indent+2);
 	}
-	foreach my $cellref (values %{$self->cells}) {
+	foreach my $cellref ($self->cells_sorted) {
 	    $cellref->dump($indent+2);
 	}
     }
